@@ -43,11 +43,11 @@ our $cache_duration;
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -75,7 +75,8 @@ You can then access the data using:
     my $row = $foo->fetchrow_hashref(customer_id => 'xyzzy');
     print Data::Dumper->new([$row])->Dump();
 
-CSV files can have empty lines of comment lines starting with '#', to make them more readable
+CSV files can have empty lines or comment lines starting with '#',
+to make them more readable.
 
 If the table has a column called "entry", sorts are based on that
 To turn that off, pass 'no_entry' to the constructor, for legacy
@@ -354,7 +355,7 @@ sub _open {
 				}
 				$dbh->func($table, 'XML', $slurp_file, 'xmlsimple_import');
 			} else {
-				throw Error::Database(-file => "$dir/$table");
+				throw Database::Abstraction::Error(-file => "$dir/$table");
 			}
 			$self->{'type'} = 'XML';
 		}
